<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#5bc08c';
	$secondary_color = '#666';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$coupon_position_choices = array(
		'choice-1' => 'After Recent Posts section',		
		'choice-2' => 'Before Recent Posts section'
	);

	$coupon_style_choices = array(
		'choice-1' => 'Hidden and click to reveal',
		'choice-2' => 'Visible for all visitors'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'makemoney-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	
	
	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);			

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['primary-nav-heading'] = array(
		'id' => 'primary-nav-heading',
		'label'   => __( 'Mobile Primary Menu Heading Text', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Pages', 'makemoney-pro'),
	);

	$options['secondary-nav-heading'] = array(
		'id' => 'secondary-nav-heading',
		'label'   => __( 'Mobile Secondary Menu Heading Text', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Categories', 'makemoney-pro'),
	);	
	
	$options['featured-content-on'] = array(
		'id' => 'featured-content-on',
		'label'   => __( 'Display featured content on homepage', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-coupons-on'] = array(
		'id' => 'featured-coupons-on',
		'label'   => __( 'Display featured coupons on homepage', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-coupons-position'] = array(
		'id' => 'featured-coupons-position',
		'label'   => __( 'Featured coupons section position', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $coupon_position_choices,		
		'default' => 'choice-1',
	);	

	$options['featured-coupons-heading'] = array(
		'id' => 'featured-coupons-heading',
		'label'   => __( 'Featured coupons section heading', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Deals & Coupon Codes',		
	);

	$options['featured-coupons-num'] = array(
		'id' => 'featured-coupons-num',
		'label'   => __( 'Number of featured coupons to show', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '3'
	);			

	$options['coupons-page-desc'] = array(
		'id' => 'coupons-page-desc',
		'label'   => __( 'Coupons page description', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => 'You may enter description for the coupon page here.',		
	);

	$options['coupon-style'] = array(
		'id' => 'coupon-style',
		'label'   => __( 'How coupons displayed on single coupon page', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $coupon_style_choices,
		'default' => 'choice-1'
	);			

	$options['entry-excerpt-length'] = array(
		'id' => 'entry-excerpt-length',
		'label'   => __( 'Number of words to show on excerpt', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '38',		
	);

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Display featured image on single posts', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);	

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['header-social-on'] = array(
		'id' => 'header-social-on',
		'label'   => __( 'Display social icons on site header', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['facebook-url'] = array(
		'id' => 'facebook-url',
		'label'   => __( 'Your Facebook URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);

	$options['twitter-url'] = array(
		'id' => 'twitter-url',
		'label'   => __( 'Your Twitter URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['google-plus-url'] = array(
		'id' => 'google-plus-url',
		'label'   => __( 'Your Google+ URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['youtube-url'] = array(
		'id' => 'youtube-url',
		'label'   => __( 'Your YouTube URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['linkedin-url'] = array(
		'id' => 'linkedin-url',
		'label'   => __( 'Your LinkedIn URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['pinterest-url'] = array(
		'id' => 'pinterest-url',
		'label'   => __( 'Your Pinterest URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['rss-url'] = array(
		'id' => 'rss-url',
		'label'   => __( 'Your RSS feed URL', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'makemoney-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);			

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'makemoney-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );